@@ -96,7 +96,8 @@ def append_empty_shap_columns(df):
         "pos_shap_scores",
         "pos_patient_values",
         "pos_shap_scores_w",
-        "pos_shap_percentile" "neg_factors",
+        "pos_shap_percentile",
+        "neg_factors",
         "neg_shap_scores",
         "neg_patient_values",
         "neg_shap_scores_w",
